==> com.liferay.object.api-66.0.0-sources.jar: com/liferay/object/constants/ObjectFieldSettingConstants.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.object.constants;

/**
 * @author Feliphe Marinho
 */
public class ObjectFieldSettingConstants {

	public static final String NAME_ACCEPTED_FILE_EXTENSIONS =
		"acceptedFileExtensions";

	public static final String NAME_DEFAULT_VALUE = "defaultValue";

	public static final String NAME_DEFAULT_VALUE_TYPE = "defaultValueType";

	public static final String NAME_FILE_SOURCE = "fileSource";

	public static final String NAME_FILTERS = "filters";

	public static final String NAME_MAX_FILE_SIZE = "maximumFileSize";

	public static final String NAME_MAX_LENGTH = "maxLength";

	public static final String NAME_OBJECT_DEFINITION_1_SHORT_NAME =
		"objectDefinition1ShortName";

	public static final String NAME_OBJECT_RELATIONSHIP_ERC_OBJECT_FIELD_NAME =
		"objectRelationshipERCObjectFieldName";

	public static final String NAME_SHOW_COUNTER = "showCounter";

	public static final String NAME_SHOW_FILES_IN_DOCS_AND_MEDIA =
		"showFilesInDocumentsAndMedia";

	public static final String NAME_STATE_FLOW = "stateFlow";

	public static final String NAME_STORAGE_DL_FOLDER_PATH =
		"storageDLFolderPath";

	public static final String NAME_UNIQUE_VALUES = "uniqueValues";

	public static final String VALUE_DOCS_AND_MEDIA = "documentsAndMedia";

	public static final String VALUE_EXPRESSION_BUILDER = "expressionBuilder";

	public static final String VALUE_INPUT_AS_VALUE = "inputAsValue";

	public static final String VALUE_USER_COMPUTER = "userComputer";

}

==> com.liferay.object.api-71.0.0-sources.jar: com/liferay/object/constants/ObjectFieldSettingConstants.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.object.constants;

/**
 * @author Feliphe Marinho
 */
public class ObjectFieldSettingConstants {

	public static final String NAME_ACCEPTED_FILE_EXTENSIONS =
		"acceptedFileExtensions";

	public static final String NAME_DEFAULT_VALUE = "defaultValue";

	public static final String NAME_DEFAULT_VALUE_TYPE = "defaultValueType";

	public static final String NAME_FILE_SOURCE = "fileSource";

	public static final String NAME_FILTERS = "filters";

	public static final String NAME_MAX_FILE_SIZE = "maximumFileSize";

	public static final String NAME_MAX_LENGTH = "maxLength";

	public static final String NAME_OBJECT_DEFINITION_1_SHORT_NAME =
		"objectDefinition1ShortName";

	public static final String NAME_OBJECT_RELATIONSHIP_ERC_OBJECT_FIELD_NAME =
		"objectRelationshipERCObjectFieldName";

	public static final String NAME_SHOW_COUNTER = "showCounter";

	public static final String NAME_SHOW_FILES_IN_DOCS_AND_MEDIA =
		"showFilesInDocumentsAndMedia";

	public static final String NAME_STATE_FLOW = "stateFlow";

	public static final String NAME_STORAGE_DL_FOLDER_PATH =
		"storageDLFolderPath";

	public static final String NAME_TIME_STORAGE = "timeStorage";

	public static final String NAME_UNIQUE_VALUES = "uniqueValues";

	public static final String VALUE_CONVERT_TO_UTC = "convertToUTC";

	public static final String VALUE_DOCS_AND_MEDIA = "documentsAndMedia";

	public static final String VALUE_EXPRESSION_BUILDER = "expressionBuilder";

	public static final String VALUE_INPUT_AS_VALUE = "inputAsValue";

	public static final String VALUE_USE_INPUT_AS_ENTERED = "useInputAsEntered";

	public static final String VALUE_USER_COMPUTER = "userComputer";

}
